from setuptools import setup, find_packages

with open("README.md", "r") as f:
    long_description = f.read()


setup(
    name="bahy_bot_maker",
    version="0.4",
    packages=find_packages(),
    install_requires=[
        "annotated-types==0.7.0",
        "anyio==4.8.0",
        "arabic-reshaper==3.0.0",
        "asttokens==3.0.0",
        "atproto==0.0.56",
        "certifi==2024.12.14",
        "cffi==1.17.1",
        "click==8.1.8",
        "comm==0.2.2",
        "cryptography==43.0.3",
        "debugpy==1.8.11",
        "decorator==5.1.1",
        "dnspython==2.7.0",
        "executing==2.1.0",
        "h11==0.14.0",
        "httpcore==1.0.7",
        "httpx==0.27.2",
        "idna==3.10",
        "ipykernel==6.29.5",
        "ipython==8.31.0",
        "jedi==0.19.2",
        "jupyter_client==8.6.3",
        "jupyter_core==5.7.2",
        "libipld==3.0.0",
        "matplotlib-inline==0.1.7",
        "nest-asyncio==1.6.0",
        "packaging==24.2",
        "parso==0.8.4",
        "pexpect==4.9.0",
        "platformdirs==4.3.6",
        "prompt_toolkit==3.0.48",
        "psutil==6.1.1",
        "ptyprocess==0.7.0",
        "pure_eval==0.2.3",
        "pycparser==2.22",
        "pydantic==2.10.5",
        "pydantic_core==2.27.2",
        "Pygments==2.19.1",
        "python-bidi==0.6.3",
        "python-dateutil==2.9.0.post0",
        "python-dotenv==1.0.1",
        "pyzmq==26.2.0",
        "six==1.17.0",
        "sniffio==1.3.1",
        "stack-data==0.6.3",
        "tornado==6.4.2",
        "traitlets==5.14.3",
        "typing_extensions==4.12.2",
        "wcwidth==0.2.13",
        "websockets==13.1",
    ],
    entry_points={
        "console_scripts": [
            "bahy_bot_maker=bahy_bot_maker:did_it_work",
        ],
    },
    author="Bahy",
    long_description=long_description,
    long_description_content_type="text/markdown",
    description="A package for creating bots on bluesky",
)
